@@ -24,6 +24,18 @@ impl SourceTextInfo {
     // todo(dsherret): re-enable once stripped in deno_graph
     // debug_assert!(!text.starts_with(BOM_CHAR));
 
+    // todo(dsherret): don't strip this here as it may require a clone
+    let text = if text.starts_with(BOM_CHAR) {
+      let mut text = match Arc::try_unwrap(text) {
+        Ok(text) => text,
+        Err(text) => text.to_string(),
+      };
+      strip_bom_mut(&mut text);
+      Arc::new(text)
+    } else {
+      text
+    };
+
     Self::with_indent_width(start_pos, text, 2)
   }
 
